{% layout 'layouts/html.liquid' %}

{% block head %}
<title>{{ page.title }}</title>
{% endblock %}

{% block content %}

<div class="d-flex align-items-stretch pd-reader">
    <div id="left-nav">
        <div class="left-nav-controls mb-3">
            <button class="toggle-button" type="button" data-bs-toggle="collapse" data-bs-target="#readerLeftNav" aria-expanded="false" aria-controls="readerLeftNav">
                <div class="hamburger-lines">
                    <span class="line line1"></span>
                    <span class="line line2"></span>
                    <span class="line line3"></span>
                </div>
            </button>
        </div>

        <div id="readerLeftNav" class="collapse collapse-horizontal left-nav-menu">
            <nav style="width:300px">
                <div class="nav flex-column nav-pills" role="tablist" aria-orientation="vertical">
                    <button class="nav-link active" id="nav-toc" data-page-slug="toc" data-bs-toggle="pill" data-bs-target="#page-toc" type="button" role="tab" aria-controls="page-toc" aria-selected="true">Index of Contents</button>
                    {% for page in acimWb %}
                        <button class="nav-link" id="nav-{{ page.slug }}" data-page-slug="{{ page.slug }}" data-bs-toggle="pill" data-bs-target="#page-{{ page.slug }}" aria-controls="page-{{ page.slug }}" aria-selected="false" type="button" role="tab" >{% if page.section_type == 'lesson' %}{{ page.number }}. {% endif %}{{ page.title }}</button>
                    {% endfor %}
                </div>
            </nav>
        </div>
        <script>
            // click handler when clicking on navlink
            // change the window location hash on click
            // scroll to top of reader on click
            var navLinks = [].slice.call(document.querySelectorAll('#readerLeftNav .nav-link'));
            navLinks.forEach(function (link) {
                link.addEventListener('click', function (event) {
                    var pageSlug = event.target.dataset.pageSlug;
                    window.history.pushState({}, '', `#${pageSlug}`);
                    window.location.hash = pageSlug;
                    window.appData = window.appData || {};
                    window.appData.pageSlug = pageSlug;

                    if (pageSlug !== 'toc') {
                        var tocLink = document.getElementById(`toc-${pageSlug}`);
                        tocLink.classList.add('visited');
                    }

                    var top = $('#main-content').offset().top - 50;
                    window.scrollTo({ top: top, behavior: 'smooth' });
                });
            });
        </script>
    </div>

    <div id="main-content" class="p-4 md-5">
        <div class="tab-content" id="main-content-content">

            <!-- table of contents page -->
            <div class="tab-pane fade show active" id="page-toc" role="tabpanel" aria-labelledby="nav-toc">
                <h1><i style="font-size:.95em">A Course in Miracles</i> Workbook</h1>
                <h2>Index of Contents</h2>
                {% for page in acimWb %}
                    <a class="toc-link d-block pb-2" id="toc-{{ page.slug }}" data-page-slug="{{ page.slug }}" aria-controls="page-{{ page.slug }}" href="#{{ page.slug }}">{% if page.section_type == 'lesson' %}{{ page.number }}. {% endif %}{{ page.title }}</a>
                {% endfor %}
                <script>
                    // handler for clicking on a toc link
                    // click the corresponding nav menu link
                    var tocLinks = [].slice.call(document.querySelectorAll('#page-toc .toc-link'));
                    tocLinks.forEach(function (link) {
                        link.addEventListener('click', function (event) {
                            var pageSlug = event.target.dataset.pageSlug;
                            var navLink = document.querySelector(`#nav-${pageSlug}`);
                            if (navLink) navLink.click();
                        });
                    });
                </script>
            </div>

            <!-- >content pages -->
            {% for page in acimWb %}
                <div class="tab-pane fade" id="page-{{ page.slug }}" role="tabpanel" aria-labelledby="nav-{{ page.slug }}">
                    <h2 class="mb-4">{{ page.title }}</h2>
                    {{ page.content }}
                </div>
            {% endfor %}
        </div>
        <div class="main-content-controls mt-4">
            <button id="tocLink" class="btn btn-link w-100">Return to Index</button>
            <script>
                var tocLink = document.getElementById('tocLink');
                tocLink.addEventListener('click', function (event) {
                    var pageSlug = window.appData.pageSlug;
                    var navLink = document.querySelector(`#nav-toc`);
                    navLink.click();

                    setTimeout(function() {
                        var top = $(`#toc-${pageSlug}`).offset().top - 50;
                        window.scrollTo({ top: top, behavior: 'smooth' });
                    }, 500);
                })
            </script>
        </div>
    </div>
</div>

<script>
    // Handle if user navigates with hash
    $(document).ready(function() {
        if (!window.location.hash) return;
        var pageSlug = window.location.hash.slice(1);
        var navLink = document.querySelector(`#nav-${pageSlug}`);
        if (navLink) navLink.click();
    });

    window.onhashchange = function() {
        var pageSlug = window.location.hash.slice(1);
        var navLink = document.querySelector(`#nav-${pageSlug}`);
        if (navLink) navLink.click();
    };
</script>

<style>
.pd-reader { max-width: 990px; margin: auto; border: 1px solid #ddd;}
.pd-reader #left-nav { position:relative; transition: all .3s; background-color: #ddd; }
#left-nav .left-nav-controls { display:flex; justify-content:center; }
.pd-reader #main-content { min-height: 100vh; transition: all .3s; }

#readerLeftNav .nav-link {
    font-size: .9em;
    padding: .25rem .5rem;
    text-align: left;
    color: #333;
}

#readerLeftNav .nav-link.active {
    background-color: white;
    color: #000;
}

.pd-reader .toggle-button { width: 50px; height:50px; display:flex; justify-content:center; align-items: center; border-color: transparent; background-color: #777; }

.hamburger-lines {
    height: 26px;
    width: 32px;
    display: flex;
    flex-direction: column;
    justify-content: space-between;
}

.hamburger-lines .line {
    display: block;
    height: 4px;
    width: 100%;
    border-radius: 10px;
    background: #ddd;
}

.hamburger-lines .line1 {
    transform-origin: 0% 0%;
    transition: transform 0.4s ease-in-out;
}

.hamburger-lines .line2 {
    transition: transform 0.2s ease-in-out;
}

.hamburger-lines .line3 {
    transform-origin: 0% 100%;
    transition: transform 0.4s ease-in-out;
}

#page-toc .toc-link {
    color: #007;
}
#page-toc .toc-link:hover {
    color: #0a53be;
}
#page-toc .toc-link.visited {
    color: #1764ef;
}
</style>

{% endblock %}

<!--thoughts, prayers, well wishes, good vibes
warm regards, blessings-->